REST Clients
============

The :class:`~etoropy.RestClient` facade composes nine specialized sub-clients,
one per API domain.

RestClient
----------

.. autoclass:: etoropy.RestClient
   :members:
   :show-inheritance:

MarketDataClient
----------------

.. autoclass:: etoropy.MarketDataClient
   :members:
   :show-inheritance:

TradingExecutionClient
----------------------

.. autoclass:: etoropy.TradingExecutionClient
   :members:
   :show-inheritance:

TradingInfoClient
-----------------

.. autoclass:: etoropy.TradingInfoClient
   :members:
   :show-inheritance:

WatchlistsClient
----------------

.. autoclass:: etoropy.WatchlistsClient
   :members:
   :show-inheritance:

FeedsClient
-----------

.. autoclass:: etoropy.FeedsClient
   :members:
   :show-inheritance:

ReactionsClient
---------------

.. autoclass:: etoropy.ReactionsClient
   :members:
   :show-inheritance:

DiscoveryClient
---------------

.. autoclass:: etoropy.DiscoveryClient
   :members:
   :show-inheritance:

UsersInfoClient
---------------

.. autoclass:: etoropy.UsersInfoClient
   :members:
   :show-inheritance:

PiDataClient
-------------

.. autoclass:: etoropy.PiDataClient
   :members:
   :show-inheritance:
